"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.classNames = exports.Thumbnail = exports.Screenshot = exports.Report = exports.Divider = exports.Comparison = void 0;

var _react = _interopRequireDefault(require("react"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

var encode = function encode(value) {
  return value.replace(/['<>\u00A0-香<>\&]/gim, function (i) {
    return '&#' + i.charCodeAt(0) + ';';
  });
};

var flatten = function flatten(v) {
  return v.reduce(function (ary, v) {
    if (Array.isArray(v)) {
      ary.push.apply(ary, _toConsumableArray(flatten(v)));
    } else {
      ary.push(v);
    }

    return ary;
  }, []);
};

var VOID_TAGS = ["br", "img", "hr"];

var isVoid = function isVoid(v) {
  return VOID_TAGS.includes(v);
};

var createElement = function createElement(tag, attributes) {
  for (var _len = arguments.length, children = new Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
    children[_key - 2] = arguments[_key];
  }

  if (typeof tag === "function") {
    return tag(_objectSpread(_objectSpread({}, attributes), {}, {
      children: children
    }));
  }

  var buffer = ["<" + tag + ""];

  for (var key in attributes) {
    var value = attributes[key];

    if (key === "className") {
      key = "class";
    }

    if (key === "ref") {
      continue;
    }

    if (key === "style") {
      value = stringifyStyle(value);
    } else if (typeof value === "string") {
      value = encode(value);
    }

    buffer.push(" " + key + "=\"" + value + "\"");
  }

  if (isVoid(tag)) {
    buffer.push("/>");
    return buffer.join("");
  }

  buffer.push(">");
  buffer.push(flatten(children).filter(function (v) {
    return v !== false && v != null;
  }).join(""));
  buffer.push("</" + tag + ">");
  return buffer.join("");
};

var stringifyStyle = function stringifyStyle(value) {
  return Object.entries(value).map(function (_ref) {
    var _ref2 = _slicedToArray(_ref, 2),
        key = _ref2[0],
        value = _ref2[1];

    return key + ":" + value;
  }).join(";");
};

var Fragment = function Fragment(props) {
  return flatten(props.children).join("");
};

var _vanilla = {
  createElement: createElement,
  Fragment: Fragment,
  forwardRef: function forwardRef(v) {
    return v;
  },
  memo: function memo(v) {
    return v;
  }
};

function getDefault(module) {
  return module["default"] || module;
}

function castStyle(value) {
  var tov = _typeof(value);

  if (tov === "object" || tov !== "string" || !value) return value;
  return value.trim().split(";").reduce(function (obj, keyValue) {
    var kvp = keyValue.split(":");
    var key = kvp[0];
    var value = kvp[1];
    if (!value || value === "undefined") return obj;
    var trimmedValue = value.trim();
    if (trimmedValue === "undefined" || !trimmedValue) return obj;
    obj[key.trim()] = trimmedValue;
    return obj;
  }, {});
}

var classNames = {};
exports.classNames = classNames;

var Thumbnail = _vanilla.memo(_vanilla.forwardRef(function Thumbnail(props, ref) {
  return _vanilla.createElement("a", {
    "className": "_d4983fd7 _6072d14d _pub-6072d14d" + (props["class"] ? " " + props["class"] : "") + (props["active"] ? " " + "_6072d14d_active _pub-6072d14d_active active" : "") + (props["hasChanges"] ? " " + "_6072d14d_has-changes _pub-6072d14d_has-changes has-changes" : "") + (props["noChanges"] ? " " + "_6072d14d_no-changes _pub-6072d14d_no-changes no-changes" : ""),
    "ref": ref,
    "id": props["id"],
    "href": props["href"],
    "style": castStyle("--background: url(" + props["src"] + ");")
  }, _vanilla.createElement("div", {
    "className": "_4832e257 _6072d14d _pub-6072d14d"
  }, _vanilla.createElement("span", {
    "className": "_8bd348df _6072d14d _pub-6072d14d"
  }, props["title"] || "Untitled")), _vanilla.createElement("div", {
    "className": "_d13bb3ed _6072d14d _pub-6072d14d" + " " + "_6072d14d_img-container _pub-6072d14d_img-container img-container " + (props["bgClassName"] ? " " + props["bgClassName"] : "")
  }, null));
}));

exports.Thumbnail = Thumbnail;

var Comparison = _vanilla.memo(_vanilla.forwardRef(function Comparison(props, ref) {
  return _vanilla.createElement("div", {
    "className": "_3dfb9ae2 _6072d14d _pub-6072d14d",
    "ref": ref
  }, props["children"]);
}));

exports.Comparison = Comparison;

var Screenshot = _vanilla.memo(_vanilla.forwardRef(function Screenshot(props, ref) {
  return _vanilla.createElement("div", {
    "className": "_d3f5fbce _6072d14d _pub-6072d14d" + (props["a"] ? " " + "_6072d14d_a _pub-6072d14d_a a" : "") + (props["b"] ? " " + "_6072d14d_b _pub-6072d14d_b b" : "") + (props["c"] ? " " + "_6072d14d_c _pub-6072d14d_c c" : ""),
    "ref": ref
  }, _vanilla.createElement("div", {
    "className": "_4f3b4a8b _6072d14d _pub-6072d14d"
  }, props["title"]), _vanilla.createElement("div", {
    "className": "_d6321b31 _6072d14d _pub-6072d14d"
  }, props["children"]));
}));

exports.Screenshot = Screenshot;

var Report = _vanilla.memo(_vanilla.forwardRef(function Report(props, ref) {
  return _vanilla.createElement("div", {
    "className": "_344dd6c9 _6072d14d _pub-6072d14d",
    "ref": ref
  }, _vanilla.createElement("div", {
    "className": "_45a56781 _6072d14d _pub-6072d14d"
  }, props["sidebar"]), _vanilla.createElement("div", {
    "className": "_dcac363b _6072d14d _pub-6072d14d"
  }, _vanilla.createElement("div", {
    "className": "_c325ee27 _6072d14d _pub-6072d14d"
  }, _vanilla.createElement("h1", {
    "className": "_ad5af615 _6072d14d _pub-6072d14d"
  }, props["title"]), _vanilla.createElement("span", {
    "className": "_3453a7af _6072d14d _pub-6072d14d"
  }, props["subtitle"])), props["content"]), _vanilla.createElement("div", {
    "className": "_abab06ad _6072d14d _pub-6072d14d"
  }, null));
}));

exports.Report = Report;

var Divider = _vanilla.memo(_vanilla.forwardRef(function Divider(props, ref) {
  return _vanilla.createElement("hr", {
    "className": "_c79553aa _6072d14d _pub-6072d14d",
    "ref": ref
  }, null);
}));

exports.Divider = Divider;